@@ -1,5 +1,5 @@
-import mon
-from install import install, mirror_install
+import mon, pkg
+from install import install, mirror_install, repo_install
 from uninstall import uninstall
 
 # Allow to set some information about this distro
