@@ -3,7 +3,7 @@ execnet: pure python lib for connecting to local and remote Python Interpreters.
 
 (c) 2012, Holger Krekel and others
 """
-__version__ = '1.1-ad3'
+__version__ = '1.2.0.dev2-ad1'
 
 from . import apipkg
 
@@ -12,6 +12,7 @@ apipkg.initpkg(__name__, {
     'SocketGateway':    '.deprecated:SocketGateway',
     'SshGateway':       '.deprecated:SshGateway',
     'makegateway':      '.multi:makegateway',
+    'set_execmodel':    '.multi:set_execmodel',
     'HostNotFound':     '.gateway_bootstrap:HostNotFound',
     'RemoteError':      '.gateway_base:RemoteError',
     'TimeoutError':     '.gateway_base:TimeoutError',
@@ -22,17 +23,11 @@ apipkg.initpkg(__name__, {
     'default_group':    '.multi:default_group',
     'dumps':            '.gateway_base:dumps',
     'loads':            '.gateway_base:loads',
+    'load':             '.gateway_base:load',
+    'dump':             '.gateway_base:dump',
     'DataFormatError':  '.gateway_base:DataFormatError',
 })
 
 # CHANGELOG
 #
-# 1.1-ad3: Catch more `TypeError` if the connection is closing but the channel attempts
-# to write. We now check is `struct.pack` is not None to proceed.
-# Issue: https://bitbucket.org/hpk42/execnet/issue/22/structpack-can-be-none-sometimes-spits
-#
-# 1.1-ad2: Allow for `sudo python` on local popen gateways
-# Issue: https://bitbucket.org/hpk42/execnet/issue/21/support-sudo-on-local-popen
-#
-# 1.1-ad1: `if case` to check if `Message` is None and avoid AttributeErrors
-# Issue: https://bitbucket.org/hpk42/execnet/issue/20/attributeerror-nonetype-object-has-no
+# 1.2.0-ad1: Patch `if case` in to_io method to prevent AttributeErrors
