@@ -5,16 +5,13 @@ import uuid
 import struct
 import time
 import base64
-import socket
 
-from . import exc
-from .cliutil import priority
-from .conf import CephConf
-from . import hosts
-from .util import arg_validators, ssh
-from .misc import mon_hosts
-from .lib.remoto import process
-from .connection import get_local_connection
+from ceph_deploy.cliutil import priority
+from ceph_deploy import conf, hosts, exc
+from ceph_deploy.util import arg_validators, ssh, net
+from ceph_deploy.misc import mon_hosts
+from ceph_deploy.lib.remoto import process
+from ceph_deploy.connection import get_local_connection
 
 
 LOG = logging.getLogger(__name__)
@@ -32,22 +29,6 @@ def generate_auth_key():
     return base64.b64encode(header + key)
 
 
-def get_nonlocal_ip(host):
-    """
-    Search result of getaddrinfo() for a non-localhost-net address
-    """
-    try:
-        ailist = socket.getaddrinfo(host, None)
-    except socket.gaierror:
-        raise exc.UnableToResolveError(host)
-    for ai in ailist:
-        # an ai is a 5-tuple; the last element is (ip, port)
-        ip = ai[4][0]
-        if not ip.startswith('127.'):
-            return ip
-    raise exc.UnableToResolveError(host)
-
-
 def ssh_copy_keys(hostname, username=None):
     LOG.info('making sure passwordless SSH succeeds')
     if ssh.can_connect_passwordless(hostname):
@@ -95,7 +76,7 @@ def ssh_copy_keys(hostname, username=None):
 
 def new(args):
     LOG.debug('Creating new cluster named %s', args.cluster)
-    cfg = CephConf()
+    cfg = conf.ceph.CephConf()
     cfg.add_section('global')
 
     fsid = uuid.uuid4()
@@ -106,8 +87,7 @@ def new(args):
 
     for (name, host) in mon_hosts(args.mon):
         LOG.debug('Resolving host %s', host)
-        ip = None
-        ip = get_nonlocal_ip(host)
+        ip = net.get_nonlocal_ip(host)
         LOG.debug('Monitor %s at %s', name, ip)
         mon_initial_members.append(name)
         mon_host.append(ip)
